@@ -159,8 +159,12 @@ def handle_trigger(
         else trigger_definition["EventBatchingCondition"]
     )
 
-    actions = [{"JobName": job_name}] if 'Actions' not in trigger_definition else trigger_definition['Actions']
-    trigger_definition['Actions'] = actions
+    actions = (
+        [{"JobName": job_name}]
+        if "Actions" not in trigger_definition
+        else trigger_definition["Actions"]
+    )
+    trigger_definition["Actions"] = actions
 
     if new_trigger:
         response = glueclient.create_trigger(
